#
# spec file for package orage
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orage
Version:        4.20.0
Release:        1.3
Summary:        Time-managing Application for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          Productivity/Office/Organizers
URL:            https://docs.xfce.org/panel-plugins/orage/start
Source:         https://archive.xfce.org/src/apps/orage/4.20/%{name}-%{version}.tar.bz2
Source1:        README.SUSE
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0) >= 2.58.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.58.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(libical) >= 3.0
BuildRequires:  pkgconfig(libnotify) >= 0.7.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.16.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.16.0
Recommends:     %{name}-lang = %{version}-%{release}
# use /usr/bin/play to play notification sounds
Recommends:     sox
Provides:       orage-doc = %{version}-%{release}
Provides:       xfcalendar = %{version}-%{release}
Obsoletes:      orage-doc <= %{version}-%{release}
Obsoletes:      xfcalendar < %{version}-%{release}

%description
Orage is a fast and easy to use graphical calendar for the Xfce desktop
environment. It uses the portable ical format and includes common calendar
features like repeating appointments and multiple alarming possibilities. Orage
does not have group calendar features and can only be used for single user.

%lang_package

%prep
%autosetup
cp %{SOURCE1} .

%build
%configure
%make_build

%install
%make_install

%fdupes %{buildroot}%{_datadir}

%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc README.md AUTHORS NEWS README.SUSE
%{_bindir}/orage
%dir %{_datadir}/%{name}
%{_datadir}/orage/sounds/
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/dbus-1/services/org.xfce.orage.service
%dir %{_datadir}/themes/Default/orage-4.0
%{_datadir}/themes/Default/orage-4.0/gtk.css

%files lang -f %{name}.lang

%changelog
* Tue Jan  7 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0
  * Redesigned appointment window recurrence tab. Related with
    Issue #23.
  * Internal changes, changed appointment window to subclass of
    GtkWindow
  * Internal changes, changed mainbox to subclass of
    GtkApplicationWindow (MR !48)
  * Moved internal CSS string to separte theme file (MR !47,
    MR !65)
  * Added command line parameter '-i' to import ICS files
  * Rudimentary synchronization support: added support for calling a
    user-specified synchronization command
  * Fixed Gtk-CRITICAL message while adding new appointment.
  * Replaced Orage wake up detection with wake up detection from
    panel clock plugin.
  * Fixed memory leak and error handling when timezone info loading
    fails. (MR !56)
  * Added support for TZDIR environment variable (Issue #28).
  * Updated desktop file: added actions for 'today' and 'new appointment'
    (MR !58), added Keywords (MR! 64)
  * Recurrence tab improvements: fixed dependency from ICAL RRULE
    (MR !59, MR !52, Issue #23, Issue #29)
  * Use gettext and XDT_VERSION_INIT (MR !60)
  * Internal changes, changed day window (MR !62)
  * Disabled tray icon by default, (MR !66, MR !64)
  * Translation Updates
* Wed Feb  8 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.0
  * Changed Orage internal time and data strings to GDateTime (MR !20)
  * In event list, fixed event hiding when event start at 00:00 and
    end 00:00 in same date (this kind event can be created when
    creating full day event, save event and then unset full day option).
    (MR !20)
  * Removed bundled libical (Issue #5)
  * Removed panel plugin (Issue #11)
  * Removed GlobalTime (Issue #12)
  * Replaced old Orage icons (Issue #16) and removed 160x160 icons
  * Replaced deprecated dbus-glib with GDBus (Issue #4)
  * Changed event attach order in day view window (Issue #15)
  * Added Wayland support (Issue #2)
  * Fixed orage_persistent_alarms.txt not found messages (MR !35)
  * Fixed after wakeup tray icon updating (Issue #14)
  * Changed alarm_structure to reference counted structure. This
    fixes warnings about memory leaks (MR !38, replaces MR !8)
  * Changed libnotify minimum version to 0.7.0 (MR !39)
  * Disabled sound alarm when sound command is not set (MR !40)
  * Fixed large ical file import (Issue #8)
  * Translation Updates
* Fri Apr  8 2022 Maurizio Galli <maurizio.galli@suse.com>
- Fix categories in org.xfce.orage.globaltime.desktop
* Wed Mar 23 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.16.0
  * Finalize port to GTK 3, small fixes and cleanup for 4.16.0
  * Add new application icon (!18)
  * Fix some memory leaks
  * i18n: Use `xfce_textdomain()` to initialize translations
  * Trace messages cleanup (!15)
  * Update COPYING (Issue #10, !17)
  * Use stdout and stderr correctly in main.c
  * Build tz_convert only with bundled libical (!14)
  * Switch to reverse-DNS naming for icon and desktop files (!13)
  * D-Bus service cleanup (!12)
  * Fix `orage_exec()` and its calls
  * Update project files (!10)
  * Fixed strptime parse issue on FreeBSD (#6, !11)
  * Fix make distcheck warnning
  * Fixed libpopt detection on FreeBSD (!9)
  * Fix build warnings 3: Clang static analyzer (!6)
  * Added 'git' to program version string and 'sed' check (!7)
  * Fix build warnings 2: Compilation (!4)
  * Fix build warnings 1: Autotools (!3)
  * Add basic GitLab pipeline (!2)
* Sat Mar  3 2018 seife+obs@b1-systems.com
- add 0001-fix-build-with-libical-version-3.patch (bxo#13997)
- should now work with libical > 2
* Sat Mar  3 2018 jengelh@inai.de
- Explicitly request old libical
* Sun Apr 12 2015 gber@opensuse.org
- update to version 4.12.1
  - bxo#11807: Wrong plugin module name
  - bxo#11380: Error in manpage
- drop obsolete orage-fix-plugin-filename.patch
* Thu Apr  9 2015 gber@opensuse.org
- add orage-fix-plugin-filename.patch in order to fix the plugin
  filename so that the plugin is found again (bxo#11807)
* Thu Apr  9 2015 gber@opensuse.org
- update to version 4.12.0
  - several issues reported by Coverity fixed.
  - bxo#10647: missing translations in globaltime
  - bxo#10648: missing window title translation in globaltime
  - bxo#10947: Implemented Orage vertical panel clock
  - bxo#8719: Implemented Orage panel plugin as module
  - possible to set delayed file close time
* Wed Dec 11 2013 gber@opensuse.org
- update to version 4.10.0
  - fix bxo#9249: Hourly flag missing from event window and tooltip
  - fix bxo#9830: Pick the date dialog is not localized
  - fix bxo#9014: Rename Execute button to Postpone for snooze
    alarms
  - fix bxo#9017: Clarified Delete confirmation message
  - fix bxo#9024: Clear nto used extra space from main calendar
  - fix bxo#10517: Fix archiving to use correct year
  - fix bxo#10325: Fix startup failure for some languages
  - fix bxo#10108: Use g_strdup() instead of strdup() with g_free()
  - fix bxo#10107: Fixed potential memory leak
  - fix bxo#10473: Fixed crash in file copy with missing files
  - fix bxo#10401: Use exo-open instead of fixed firefox with help
  - fix bxo#9507: Older than 1970 periodic events do not work
  - fix bxo#7929: Some foreign files show time offset in event view
  - fix bxo#8382: Some events were shown on wrong day
  - fix bxo#8508: Event ending at midnight is shown on the next day
  - fix bxo#8426: Missing translations for some timezone names
  - fix bxo#9028: Orage shows events at +0000 with some iCal files
  - fix bxo#9810: Do not show "null" when Location or Notes is empty
  - fix bxo#8231: Make the alarm type selectable for foreign files
  - fix bxo#8383: Possible to start day view on first day of week
  - fix bxo#6597: Tooltip enhacements to use Pango markup
  - fix bxo#9011: Tooltip enhacements to use smaller windows
  - fix bxo#10432: Possible to make Orage quit when asked to close
  - fix bxo#9291: Handle external updates to Orage file also
  - fix bxo#7873: Allow inserting events to foreign files
  - fix bxo#9250: New list of all events in event list window
- drop obsolete orage-do-not-hardcode-firefox.patch
- remove %%clean
- drop unnecessary removal of unsupported locales
* Fri Feb  1 2013 gber@opensuse.org
- update to version 4.8.4:
  - fix bxo#8525: Orage notifies every second on "All day events"
  - fix bxo#4817: anchor('#') does not work in help links
  - fix bxo#9243: strptime() needs _XOPEN_SOURCE_EXTENDED defined
  - fix bxo#9248: internal libical fix SSPM_UNKNOWN_MINOR_TYPE
  - fix bxo#8231: alarm type is selectable for foreign files
  - fix bxo#9739: new TODOs start as NOT completed
  - fix bxo#9738: main window sorts TODOs by due-date
  - fix bxo#9598: main window tooltip shows title and location bold
  - translation updates
- rebase and rename orage-4.8.2-use-docdir.patch to
  orage-use-docdir.patch
- add orage-do-not-hardcode-firefox.patch in order to use exo-open
  instead of hardcoding firefox
* Tue May  1 2012 gber@opensuse.org
- recommend sox so /usr/bin/play can be used to play notification
  sounds
* Sun Apr 15 2012 gber@opensuse.org
- recommend the -doc subpackage
* Fri Mar 30 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -doc subpackage
* Thu Jan  5 2012 gber@opensuse.org
- update to version 4.8.3
  - made it impossible to modify read-only events
  - added location into main calender tooltip
  - word wrap for note in appointment window
  - improved time spinners in appointment window
  - bugfixes
  - translation updates
* Thu Oct 20 2011 gber@opensuse.org
- added orage-4.8.2-use-docdir.patch in order to use docdir
  correctly
- install HTML documentation under /usr/share/xfce4/orage/html
- make the file list a bit more explicit
* Mon Sep 19 2011 gber@opensuse.org
- update to version 4.8.2
  - possible to export from shell
  - variable icon can now be changed
  - procedure alarm replacement parameters
  - hourly repeat option added
  - bugfixes
  - translation updates
* Tue Mar  8 2011 gber@opensuse.org
- update to version 4.8.1
  - bugfixes
  - translation updates
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Sat Jan 15 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Thu Jan 13 2011 gber@opensuse.org
- update to version 4.8
  - bugfixes
  - translation updates
* Fri Dec 24 2010 gber@opensuse.org
- improved description
- added some hints for migrating from older Orage versions to
  README.SUSE
* Fri Dec 24 2010 gber@opensuse.org
- remove unsupported locales
- handle xfce-xfcalendar-settings.desktop
- split off -lang subpackage
- changed globaltime.desktop category to Utility, Clock
* Wed Dec 15 2010 prusnak@opensuse.org
- updated to 4.7.6.7
  - use git snapshot to fix build with Xfce 4.8
* Thu Dec  2 2010 prusnak@opensuse.org
- updated to 4.7.5
* Sun Apr 18 2010 crrodriguez@opensuse.org
- Requires timezone
* Tue Mar 23 2010 puzel@novell.com
- fix broken build: copy README.SUSE to build directory
- add orage-4.6.1-fix-undefined-operation.patch
* Thu Mar 18 2010 prusnak@suse.cz
- add README.SUSE to documentation
* Mon Jul 27 2009 coolo@novell.com
- fix usage of %%_libexecdir
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Tue Nov 18 2008 pnemec@suse.cz
- call update_desktop_file macro on desktop files [bnc#445722]
* Tue Oct 14 2008 prusnak@suse.cz
- link against distribution libical (shared-libical.patch) [bnc#434984]
- updated to 4.5.14.0
  * Man page created for orage and globaltime
  * Globaltime added.
  - shows several clocks from different timezones
  - can be raised and hidden by clicking middle mouse
    button on orage clock panel plugin
  - has timetune feature, which makes it easy to see what
    the time is in other clocks on certain time
  * All visible dates are now in country native format (strftime (%%x))
  * All parameters now visible in preferences
  - restructured parameter screens
  * New appointment types: TODO and JOURNAL
  - TODO can be used to remember things that needs to done
  - JOURNALs are for notes and things to remember
  * Possible to rename Orage calendar files
  * External files can be used
  - it is possible to add files from other sources
    and Orage keeps track on those.
  * Export and import appointments.
  * Text search in event list
  * Orage is now dependent on local libical.
  - standard libical cannot be used due to several fixes
    done to Orage's private copy
  * Daylist view
  - possible to see calendar in day view format in addition
    to the old list view.
  * New alarms.
  - libnotify alarms
  - script type alarms
  * Possibility to set alarm based on end time also
  * Possible to define default alarm
  * Persistent alarms
  - persistent alarms are raised after Orage is started
    even if your computer or Orage has been turned off when the
    alarm happened.
  * Orage and orageclock now only wake up when needed.
  - saves battery in laptops when timer wakes up only when
    needed instead of regularly every second.
  * Main calendar now has list of events and todos.
  * Better compatibility with evolution ical files
  * Categories added
  - also possible to give colour to certain category
    and then colour is shown in even list view
* Thu May  8 2008 aj@suse.de
- Fix missing return value (missing-retval.patch)
* Mon Dec  3 2007 bwalle@suse.de
- update to 4.4.2
  o Recurrence not recurring at the limit date. Missing fix:
    convert time back to UTC when reading. Caused day to be
    incremented for -GMT timezones
  o Added missing last update time
  o Orage clock now wakes up only when needed. This fix sacrifies a
    little of accuracy to save wakeups. If seconds are not visible
    clock wakes up only once per minute
  o Updated and new translations
* Tue Apr 10 2007 bwalle@suse.de
- update to 4.4.1
  o Bug when adding All day event from iCal. All day events were
    handled wrongly in Orage.
  o Recurring events need to happen on ending date also.
  o Erroneous warning when adding panel plugin.
  o Change field before save so that spin buttons activate always.
  o Many translation updates.
* Wed Mar 21 2007 prusnak@suse.cz
- fixed errors in filelist
* Sun Jan 21 2007 bwalle@suse.de
- upgraded to 4.4.0
* Sat Nov  4 2006 bwalle@suse.de
- updated to 4.3.99.2 (4.4 rc2)
* Mon Sep  4 2006 pnemec@suse.cz
- updated to new version 4.3.99.1
* Wed Aug 23 2006 pnemec@suse.cz
- added dbus-devel to build requires
* Tue Aug  1 2006 pnemec@suse.cz
- initial comment, version is 4.3.90.2
- package moved into BuildService
- added orage-desktop.patch - small modificatin of desktop file
